@@ -100,7 +100,7 @@ gnome_canvas_shape_get_type (void)
 	static GType shape_type;
 
 	if (!shape_type) {
-		static const GTypeInfo object_info = {
+		const GTypeInfo object_info = {
 			sizeof (GnomeCanvasShapeClass),
 			(GBaseInitFunc) NULL,
 			(GBaseFinalizeFunc) NULL,
@@ -667,10 +667,10 @@ gnome_canvas_shape_unrealize (GnomeCanvasItem *item)
 	if (!item->canvas->aa) {
 		g_assert (shape->priv->gdk != NULL);
 
-		gdk_gc_unref (shape->priv->gdk->fill_gc);
+		g_object_unref (shape->priv->gdk->fill_gc);
 		shape->priv->gdk->fill_gc = NULL;
 
-		gdk_gc_unref (shape->priv->gdk->outline_gc);
+		g_object_unref (shape->priv->gdk->outline_gc);
 		shape->priv->gdk->outline_gc = NULL;
 	}
 
@@ -1285,11 +1285,11 @@ static void
 set_stipple (GdkGC *gc, GdkBitmap **internal_stipple, GdkBitmap *stipple, int reconfigure)
 {
 	if (*internal_stipple && !reconfigure)
-		gdk_bitmap_unref (*internal_stipple);
+		g_object_unref (*internal_stipple);
 
 	*internal_stipple = stipple;
 	if (stipple && !reconfigure)
-		gdk_bitmap_ref (stipple);
+		g_object_ref (stipple);
 
 	if (gc) {
 		if (stipple) {
@@ -1351,10 +1351,10 @@ gcbp_destroy_gdk (GnomeCanvasShape * shape)
 		g_assert (!gdk->outline_gc);
 
 		if (gdk->fill_stipple)
-			gdk_bitmap_unref (gdk->fill_stipple);
+			g_object_unref (gdk->fill_stipple);
 
 		if (gdk->outline_stipple)
-			gdk_bitmap_unref (gdk->outline_stipple);
+			g_object_unref (gdk->outline_stipple);
 
 		if (gdk->points)
 			g_free (gdk->points);
@@ -1433,10 +1433,10 @@ gcbp_ensure_mask (GnomeCanvasShape * shape, gint width, gint height)
 
 		window = ((GtkWidget *) (((GnomeCanvasItem *) shape)->canvas))->window;
 
-		if (ctx->clear_gc) gdk_gc_unref (ctx->clear_gc);
-		if (ctx->xor_gc) gdk_gc_unref (ctx->xor_gc);
-		if (ctx->mask) gdk_bitmap_unref (ctx->mask);
-		if (ctx->clip) gdk_bitmap_unref (ctx->clip);
+		if (ctx->clear_gc) g_object_unref (ctx->clear_gc);
+		if (ctx->xor_gc) g_object_unref (ctx->xor_gc);
+		if (ctx->mask) g_object_unref (ctx->mask);
+		if (ctx->clip) g_object_unref (ctx->clip);
 
 		ctx->mask = gdk_pixmap_new (window, width, height, 1);
 		ctx->clip = NULL;
@@ -1456,14 +1456,14 @@ gcbp_draw_ctx_unref (GCBPDrawCtx * ctx)
 {
 	if (--ctx->refcount < 1) {
 		if (ctx->clear_gc)
-			gdk_gc_unref (ctx->clear_gc);
+			g_object_unref (ctx->clear_gc);
 		if (ctx->xor_gc)
-			gdk_gc_unref (ctx->xor_gc);
+			g_object_unref (ctx->xor_gc);
 
 		if (ctx->mask)
-			gdk_bitmap_unref (ctx->mask);
+			g_object_unref (ctx->mask);
 		if (ctx->clip)
-			gdk_bitmap_unref (ctx->clip);
+			g_object_unref (ctx->clip);
 		
 		g_object_set_data (G_OBJECT (ctx->canvas), "BpathDrawCtx", NULL);
 		g_free (ctx);
