@@ -1,6 +1,6 @@
 #include <stdlib.h>
 
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
 #include <glade/glade-xml.h>
 
@@ -15,7 +15,7 @@ main (int argc, char *argv[])
 
 	gtk_init (&argc, &argv);
 
-	xml = glade_xml_new ("test-libglade-canvas.glade2", NULL, NULL);
+	xml = glade_xml_new (GLADEFILE, NULL, NULL);
 
 	g_assert (xml != NULL);
 
